@@ -1,5 +1,5 @@
+import aiohttp
 from herre.grants.base import BaseGrant
-from herre.grants.openid import OpenIdUser
 from herre.grants.refreshable import Refreshable
 from oauthlib.oauth2 import WebApplicationClient
 from herre.grants.session import OAuth2Session
@@ -8,7 +8,7 @@ import webbrowser
 from aiohttp import web
 import asyncio
 import logging
-from herre.grants.utils import build_authorize_url, build_token_url
+from herre.grants.utils import build_authorize_url, build_me_url, build_token_url
 from herre.herre import Herre
 from herre.utils import wait_for_redirect
 
@@ -16,7 +16,7 @@ logger = logging.getLogger(__name__)
 REDIRECT_PORT = 6767
 
 
-class AuthorizationCodeServerGrant(BaseGrant, Refreshable, OpenIdUser):
+class AuthorizationCodeServerGrant(BaseGrant, Refreshable):
     redirect_port: int = 6767
     redirect_timeout: int = 40
     redirect_host: str = "localhost"
@@ -52,6 +52,18 @@ class AuthorizationCodeServerGrant(BaseGrant, Refreshable, OpenIdUser):
 
         raise Exception("Could not fetch token")
 
+    async def afetch_user(self, herre: Herre, token: Token) -> User:
+        async with aiohttp.ClientSession(
+            headers={"Authorization": f"Bearer {token.access_token}"}
+        ) as session:
+            async with session.get(build_me_url(herre)) as resp:
+
+                user_json = await resp.json()
+                if "detail" in user_json:
+                    raise Exception(user_json["detail"])
+
+                return User(**user_json)
+
     async def get_path_from_redirect(self, auth_url):
         return await wait_for_redirect(
             auth_url, redirect_host="localhost", redirect_port=self.redirect_port
